@@ -13,25 +13,25 @@ def test_load_config_parts():
 
 
 def test_load_entries():
-    entries = sshconf.get_raspi_hosts(_SAMPLE_PATH)
+    entries = sshconf.get_found_hosts(_SAMPLE_PATH)
     assert entries
 
 
 def test_update_entries():
-    entries = sshconf.get_raspi_hosts(_SAMPLE_PATH)
+    entries = sshconf.get_found_hosts(_SAMPLE_PATH)
     assert entries
 
-    sshconf.update_raspi_hosts(entries, _SAMPLE_PATH, backup=False)
-    entries_2 = sshconf.get_raspi_hosts(_SAMPLE_PATH)
+    sshconf.update_found_hosts(entries, _SAMPLE_PATH, backup=False)
+    entries_2 = sshconf.get_found_hosts(_SAMPLE_PATH)
     assert entries == entries_2
 
     backup_pth = _SAMPLE_PATH + ".bak"
 
     new_entries = [sshconf.HostEntry(name="fake", User="me", HostName="you")]
-    sshconf.update_raspi_hosts(new_entries, _SAMPLE_PATH, backup=True)
-    assert new_entries == sshconf.get_raspi_hosts(_SAMPLE_PATH)
+    sshconf.update_found_hosts(new_entries, _SAMPLE_PATH, backup=True)
+    assert new_entries == sshconf.get_found_hosts(_SAMPLE_PATH)
 
-    assert entries == sshconf.get_raspi_hosts(backup_pth)
+    assert entries == sshconf.get_found_hosts(backup_pth)
 
-    sshconf.update_raspi_hosts(entries, _SAMPLE_PATH)
-    assert entries == sshconf.get_raspi_hosts(_SAMPLE_PATH)
+    sshconf.update_found_hosts(entries, _SAMPLE_PATH)
+    assert entries == sshconf.get_found_hosts(_SAMPLE_PATH)
